"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ElasticTranscoderClient_1 = require("../../ElasticTranscoderClient");
const ListPresetsCommand_1 = require("../../commands/ListPresetsCommand");
const ReadJobCommand_1 = require("../../commands/ReadJobCommand");
async function smokeTestRunner() {
    const defaultRegion = process.env.AWS_SMOKE_TEST_REGION || "us-west-2";
    let testFailed = false;
    console.log("1..2");
    console.log("# Running tests for Elastic Transcoder.");
    await (async () => {
        const client = new ElasticTranscoderClient_1.ElasticTranscoderClient({
            region: defaultRegion
        });
        const command = new ListPresetsCommand_1.ListPresetsCommand({});
        try {
            const result = await client.send(command);
            console.log("ok Elastic Transcoder ListPresets - no error expected from service");
        }
        catch (err) {
            console.log("not ok Elastic Transcoder ListPresets - no error expected from service");
            // output unexpected error information
            console.log("# " + err.message);
            err.stack.split("\n").forEach((line) => {
                console.log("# " + line);
            });
            testFailed = true;
        }
    })();
    await (async () => {
        const client = new ElasticTranscoderClient_1.ElasticTranscoderClient({
            region: defaultRegion
        });
        const command = new ReadJobCommand_1.ReadJobCommand({
            Id: "fake_job"
        });
        try {
            const result = await client.send(command);
            console.log("not ok Elastic Transcoder ReadJob - error expected from service");
            testFailed = true;
        }
        catch (err) {
            console.log("ok Elastic Transcoder ReadJob - error expected from service");
        }
    })();
    if (testFailed) {
        process.exit(1);
    }
    else {
        process.exit(0);
    }
}
// execute the test runner
smokeTestRunner();
//# sourceMappingURL=index.spec.js.map